@@ -44,7 +44,7 @@ def cannot_be_undefined(*args, **kwargs):
         f"`{kwargs['step_name']}` function must be defined either "
         f"as a decorator (`@mybot.{kwargs['step_name']}`) or by "
         f"overriding the function entirely "
-        f"(`mybot.{kwargs['step_name']}_function = <process_function>`)"
+        f"(`mybot.{kwargs['step_name']}_function = <{kwargs['step_name']}_function>`)"
     )
 
 
@@ -295,9 +295,8 @@ class Bot:
 
         # Use `partial` so we can ensure the name of the function always goes
         # to the exception.
-        # TODO:#3927 Figure out a nicer way to get the step_name in here
         self.process_function = partial(
-            cannot_be_undefined, step_name="process"
+            cannot_be_undefined, step_name=self.process.__name__
         )
         self.precompletion_function = do_nowt
         self.postprocess_function = do_nowt
