@@ -2,6 +2,17 @@ import configparser
 import os
 from inspect import ismodule
 from os import environ
+from .types import (
+    BOOL,
+    LOGGING_OPTIONS,
+    DIR_PATH_NON_EXISTING,
+    FILE_PATH_NON_EXISTING,
+    FILE_PATH_EXISTING,
+    POSITIVE_INT,
+)
+
+from click.types import STRING
+from click import BadParameter
 
 from . import defaults
 from pyqalx.config.defaults import bots
@@ -15,17 +26,18 @@ from pyqalx.core.errors import (
 class Config(dict):
     key_prefix = ""
     filename = ""
-    BOOLEAN_STATES = {
-        "1": True,
-        "yes": True,
-        "true": True,
-        "on": True,
-        "0": False,
-        "no": False,
-        "false": False,
-        "off": False,
-        True: True,
-        False: False,
+    default = "default"
+    default_type_map = {
+        "TOKEN": STRING,
+        "KEYFILE": FILE_PATH_EXISTING,
+        "LOGGING_LEVEL": LOGGING_OPTIONS,
+        "LOG_FILE_PATH": FILE_PATH_NON_EXISTING,
+        "UNPACK_SET": BOOL,
+        "UNPACK_BLUEPRINT": BOOL,
+        "UNPACK_GROUP": BOOL,
+        "MSG_BLACKOUTSECONDS": POSITIVE_INT,
+        "MAX_RETRY_500": POSITIVE_INT,
+        "FACTORY_PACK_DIR": DIR_PATH_NON_EXISTING,
     }
 
     def __init__(self):
@@ -72,23 +84,16 @@ class Config(dict):
                 "Couldn't find {}".format(cls.config_path())
             )
 
-    def from_inifile(self, profile_name="default"):
+    def from_inifile(self, profile_name=None):
+        if profile_name is None:
+            profile_name = self.default
         config_dict = self._load_inifile(profile_name=profile_name)
         self.update(config_dict)
+        self._validate(self)
 
     def __repr__(self):
         return "<%s %s>" % (self.__class__.__name__, dict.__repr__(self))
 
-    def getboolean(self, key):
-        """
-        Helper method for allowing us to handle multiple boolean values
-        """
-        # Convert to a string in case we're being given a python bool()
-        value = str(self[key])
-        if value.lower() not in self.BOOLEAN_STATES:
-            raise ValueError("Not a boolean: %s" % value)
-        return self.BOOLEAN_STATES[value.lower()]
-
     @property
     def defaults(self):
         return {
@@ -111,19 +116,77 @@ class Config(dict):
         if config_items is None:
             # We might just be writing a blank config (i.e. for `.bots`)
             config_items = {}
+        validated_items = cls._validate(config_items)
         with open(cls.config_path(), "a") as cfg:
             config_string = f"[{profile_name}]\n"
-            for config_key, config_value in config_items.items():
+            for config_key, config_value in validated_items.items():
                 config_string += f"{config_key}={config_value}\n"
             cfg.write(config_string)
 
+    @staticmethod
+    def _get_logging_details():
+        raise QalxConfigError("Must be implemented by implementing class")
+
+    def _create_log_directories(self):
+        """
+        Creates the directory structure for the log files.  Iterates through
+        a list of data from `_get_logging_details()` to handle different types
+        of logging directories for each config
+        """
+        for logging_details in self._get_logging_details():
+            # expects_file, key, dir_path = self._get_logging_details()
+            CONFIG_KEY = logging_details["CONFIG_KEY"]
+            logger_path = self[CONFIG_KEY]
+            ISFILE = logging_details["ISFILE"]
+            method = "isdir" if ISFILE else "isfile"
+            if getattr(os.path, method)(logger_path):
+                # If its a file, check it isn't already on disk as a directory,
+                # and vice-versa
+                msg = (
+                    f"`{CONFIG_KEY}`: {logger_path} exists, but it is"
+                    f" not a {'file' if ISFILE else 'directory'}."
+                )
+                raise QalxConfigError(msg)
+            if ISFILE:
+                logger_path = os.path.dirname(logger_path)
+            try:
+                os.makedirs(logger_path, exist_ok=True)
+            except (OSError, PermissionError):
+                msg = (
+                    f"`{CONFIG_KEY}`: {logger_path}"
+                    f" does not exist and it could not be created."
+                )
+                raise QalxConfigError(msg)
+
+    @classmethod
+    def _validate(cls, config_dict):
+        """
+        Validate and parse the values for the default config keys according to
+        their respective type. For the provided config_dict with raw
+        values, these are parsed and replaced
+        """
+        for config_key, config_value in config_dict.items():
+            parse_type = cls.default_type_map.get(config_key, None)
+            if parse_type is not None:
+                try:
+                    parsed_value = parse_type(config_value)
+                except BadParameter as exc:
+                    message = (
+                        "There was an error parsing the config value for "
+                        + f"{config_key}:\n\n{exc}"
+                    )
+                    raise QalxConfigError(message)
+                else:
+                    config_dict[config_key] = parsed_value
+        return config_dict
+
 
 class BotConfig(Config):
     """Works exactly like a dict but provides ways to fill it from ini files
     and environment variables.  There are two common patterns to populate the
     config.
     Either you can add them to the `.bots` file:
-        bot.config.from_botsfile(profile_name="default")
+        bot.config.from_botsfile(profile_name=BotConfig.default)
     Or alternatively you can define the configuration from environment variables
     starting with `QALX_BOT_`. These will be populated automatically
     but values defined in `.bots` will overwrite these if
@@ -133,11 +196,23 @@ class BotConfig(Config):
     use the export statement::
         export QALX_BOT_LICENCE_FILE='/path/to/licence/file'
     On windows use `set` instead.
-    :param defaults: an optional dictionary of default values
     """
 
     key_prefix = "QALX_BOT_"
     filename = ".bots"
+    default_type_map = dict(Config.default_type_map)
+    default_type_map.update(
+        {
+            "WORKER_LOG_FILE_DIR": DIR_PATH_NON_EXISTING,
+            "SAVE_INTERMITTENT": BOOL,
+            "SKIP_FINAL_SAVE": BOOL,
+            "KILL_AFTER": POSITIVE_INT,
+            "Q_WAITTIMESECONDS": POSITIVE_INT,
+            "Q_MSGBATCHSIZE": POSITIVE_INT,
+            "Q_WAITTIMEMAXSPREADING": POSITIVE_INT,
+            "MSG_WAITTIMESECONDS": POSITIVE_INT,
+        }
+    )
 
     @property
     def defaults(self):
@@ -150,19 +225,9 @@ class BotConfig(Config):
         config.update(bot_config)
         return config
 
-    def from_inifile(self, profile_name="default"):
-        super(BotConfig, self).from_inifile(profile_name)
-        # check if the the specified log directory exists. If not, try to create
-        # it, and raise a QalxConfigError in the case of OSError or PermissionError
-        if not os.path.isdir(self["WORKER_LOG_FILE_DIR"]):
-            try:
-                os.mkdir(self["WORKER_LOG_FILE_DIR"])
-            except (OSError, PermissionError):
-                msg = (
-                    "The specified worker log directory: {}"
-                    " does not exist and it could not be created."
-                ).format(self["WORKER_LOG_FILE_DIR"])
-                raise QalxConfigError(msg)
+    @staticmethod
+    def _get_logging_details():
+        return [{"CONFIG_KEY": "WORKER_LOG_FILE_DIR", "ISFILE": False}]
 
 
 class UserConfig(Config):
@@ -170,7 +235,7 @@ class UserConfig(Config):
     and environment variables.  There are two common patterns to populate the
     config.
     Either you can add them to the `.qalx_bot` file:
-        qalx_bot.config.from_qalxfile(profile_name="default")
+        qalx_bot.config.from_qalxfile(profile_name=UserConfig.default)
     Or alternatively you can define the configuration from environment variables
     starting with `QALX_USER_`. These will be populated automatically
     but values defined in `.bots` will overwrite these if
@@ -185,3 +250,7 @@ class UserConfig(Config):
 
     key_prefix = "QALX_USER_"
     filename = ".qalx"
+
+    @staticmethod
+    def _get_logging_details():
+        return [{"CONFIG_KEY": "LOG_FILE_PATH", "ISFILE": True}]
