@@ -16,8 +16,8 @@ LOG_FILE_PATH = os.path.join(
 )
 r"""The path where log files will be stored.
 
-* Windows: C:\\Users\\<User>\\AppData\\Local\\agiletek\\pyqalx\\Logs\\.qalx.log
-* Linux: /home/ben/.cache/pyqalx/log/.qalx.log
+* Windows: C:\\Users\\<User>\\AppData\\Local\\agiletek\\qalx\\Logs\\.qalx.log
+* Linux: /home/<user>/.cache/qalx/log/.qalx.log
 * Max ~/Library/Logs/qalx/.qalx.log
 
 """
@@ -60,9 +60,9 @@ r"""
 The directory where factory bot code will be packed and deployed from.
 Defaults to the following:
 
-* Windows: C:\\Users\\<User>\\AppData\\Local\\agiletek\\pyqalx
-* Linux: ~/.local/share/pyqalx
-* Mac: ~/Library/Application Support/pyqalx
+* Windows: C:\\Users\\<User>\\AppData\\Local\\agiletek\\qalx
+* Linux: ~/.local/share/qalx
+* Mac: ~/Library/Application Support/qalx
 """
 
 del APPNAME, APPAUTHOR  # These are not config keys
