@@ -170,6 +170,27 @@ class QalxAdapter(object):
             entity_class = self.entity_class
         return entity_class(response, **kwargs)
 
+    def _add_tags(self, entity):
+        """
+        Helper for applying tags to the entity before adding.  The tags
+        need to be added to the individual entity, but can only be applied
+        from the session - i.e. the user shouldn't add them manually.
+        :param entity: The entity data that is being added
+        :return: The entity data.
+        """
+        if "tags" in entity.keys():
+            # Ensures users don't get confused if they try to do
+            # `.add(tags={'my': 'tag'}).  We cannot do this in `_validate`
+            # because we only want this validation to occur on `add`
+            raise QalxError(
+                "Tags can only be added to entities via the "
+                "session.  Do `session.tags.add(name=<tag_name>, "
+                "value=<tag value>)` rather than passing a `tags` "
+                "argument to `add`"
+            )
+        entity["tags"] = self.session.tags
+        return entity
+
     def add(self, **kwargs):
         """
         Adds a new instance of `self.entity_class` or a parent class that is
@@ -186,17 +207,9 @@ class QalxAdapter(object):
             # doing a bulk insert.  This kwarg should be set on the adapter
             # that has done the validation
             kwargs = self._validate(**kwargs)
-        if "tags" in kwargs.keys():
-            # Ensures users don't get confused if they try to do
-            # `.add(tags={'my': 'tag'}).  We cannot do this in `_validate`
-            # because we only want this validation to occur on `add`
-            raise QalxError(
-                "Tags can only be added to entities via the "
-                "session.  Do `session.tags.add(name=<tag_name>, "
-                "value=<tag value>)` rather than passing a `tags` "
-                "argument to `add`"
-            )
-        kwargs["tags"] = self.session.tags
+
+        self._add_tags(kwargs)
+
         response = self._process_api_request(
             "post", self.list_endpoint(**kwargs), **kwargs
         )
@@ -237,22 +250,12 @@ class QalxAdapter(object):
         return self.find(many=False, limit=2, query=query, **kwargs)
 
     def find(
-        self,
-        query=None,
-        aggregate=None,
-        sort=None,
-        skip=0,
-        limit=25,
-        many=True,
-        **kwargs,
+        self, query=None, sort=None, skip=0, limit=25, many=True, **kwargs
     ):
         """
         Method for listing entities.
 
         :param query: The optional Mongo query to find entities
-        :param aggregate:   Optional Mongo aggregation pipeline argument that
-                            can be used to perform and return aggregation
-                            results
         :param sort: The keys to sort by
         :param skip: The number of results to skip (offset) by
         :param limit: How many results should the response be limited to
@@ -265,6 +268,15 @@ class QalxAdapter(object):
         self.session.log.debug(
             f"find {self.entity_class.entity_type} with {list_endpoint}"
         )
+        if self.session.tags:
+            # There are tags on this session, modify the query given (if
+            # necessary) to include a filter that applies those tags.
+            empty_and = {"$and": []}
+            if query is None:
+                query = empty_and
+            elif "$and" not in query:
+                query.update(empty_and)
+            query["$and"] += self.session.tags._query()
 
         if query:
             # We need to dump the query to JSON as there could be
@@ -276,14 +288,6 @@ class QalxAdapter(object):
                     "One of the keyword arguments is not JSON serializable"
                 )
 
-        if aggregate:
-            try:
-                aggregate = bson_extra.dumps(aggregate)
-            except (TypeError, ValueError, OverflowError):
-                raise QalxError(
-                    "One of the keyword arguments is not JSON serializable"
-                )
-
         resp = self._process_api_request(
             "get",
             list_endpoint,
@@ -291,16 +295,11 @@ class QalxAdapter(object):
             skip=skip,
             limit=limit,
             query=query,
-            aggregate=aggregate,
             **kwargs,
         )
-        entity_class = AggregationResult if aggregate else QalxListEntity
         entities = self._process_api_response(
-            resp, entity_class=entity_class, child=self.entity_class
+            resp, entity_class=QalxListEntity, child=self.entity_class
         )
-        # `many` argument is redundant if `aggregate` is supplied
-        if aggregate:
-            return entities
 
         if many is False:
 
@@ -320,6 +319,33 @@ class QalxAdapter(object):
                 )
         return entities
 
+    def aggregate(self, aggregate, **kwargs):
+        """
+        Method for performing an aggregation on data.
+        See https://docs.mongodb.com/manual/core/aggregation-pipeline/.  If
+        a subset of the data is required then provide the query within the
+        aggregation pipeline
+
+        :param aggregate:The aggregation pipeline
+        :type aggregate: list
+        :return: Instance of ~pyqalx.core.entities.entity.AggregationResult
+        """
+        try:
+            aggregate = bson_extra.dumps(aggregate)
+        except (TypeError, ValueError, OverflowError):
+            raise QalxError(
+                "One of the keyword arguments is not JSON serializable"
+            )
+
+        list_endpoint = self.list_endpoint(**kwargs)
+        list_endpoint += "/aggregate"
+        resp = self._process_api_request(
+            "post", list_endpoint, aggregate=aggregate, **kwargs
+        )
+        return self._process_api_response(
+            resp, entity_class=AggregationResult, child=self.entity_class
+        )
+
     def reload(self, entity, *args, **kwargs):
         """
         Reloads the current entity from the API
