@@ -1,8 +1,8 @@
 from pyqalx.core.entities import QalxListEntity
-from pyqalx.core.entities.entity import QalxFileEntity
+from pyqalx.core.entities.entity import QalxFileEntity, QalxQueueableEntity
 
 
-class Item(QalxFileEntity):
+class Item(QalxFileEntity, QalxQueueableEntity):
     """An item is the core of qalx.
 
     They are structured data or a file or some combination of the two. For example:
@@ -10,7 +10,7 @@ class Item(QalxFileEntity):
     >>> from pyqalx import QalxSession
     >>> qalx = QalxSession()
     >>> dims = qalx.item.add(data={"height":5, "width":5}, meta={"shape":"square"})
-    >>> steel = qalx.item.add(input_file="path/to/316_datasheet.pdf",
+    >>> steel = qalx.item.add(source="path/to/316_datasheet.pdf",
     ...                       data={"rho":8000, "E":193e9},
     ...                       meta={"library":"materials",
     ...                             "family":"steel",
