@@ -4,7 +4,6 @@ from datetime import datetime, timezone
 import uuid
 
 import boto3
-import dateutil
 from botocore.exceptions import ClientError
 
 from pyqalx.core.entities import QalxEntity, Group, Item, Set
@@ -49,10 +48,9 @@ class QueueMessage(threading.Thread):
         self._heartbeats = 1
         self._heartbeat = threading.Event()
         self._worker = worker
-        self._logger = self._worker.logger
+        self._log = self._worker.log
         self._queue = self._worker.queue
-        # May not be an int if its come from the config
-        self._visibility = int(visibility)
+        self._visibility = visibility
         # Start the threaded heartbeat as soon as we can to prevent
         # message timeouts expiring if it takes a while to start processing them
         self.start()
@@ -79,13 +77,13 @@ class QueueMessage(threading.Thread):
             # SQS doesn't recalculate the max timeout if it were to be given
             # a value greater than the maximum.
             visibility_timeout = MAX_VISIBILITY_TIMEOUT
-            docs = "https://docs.qalx.io/queues#in-flight-maximum"
+            docs = "https://docs.qalx.net/queues#in-flight-maximum"
             msg = (
                 f"Max visibility timeout of {MAX_VISIBILITY_TIMEOUT} reached."
                 f"The job will go back onto the queue when "
                 f"this timeout expires. See {docs} for more information. "
             )
-            self._logger.warning(msg)
+            self._log.warning(msg)
             # Stop the heartbeat, it cannot be increased any further than
             # MAX_VISIBILITY_TIMEOUT.
             self._stop_heartbeat()
@@ -100,7 +98,7 @@ class QueueMessage(threading.Thread):
             # ClientError: There was an issue changing the visibility.
             #              This could be a networking issue or the message no
             #              longer exists on the queue
-            self._logger.debug(
+            self._log.debug(
                 f"Received ClientError when extending heartbeat."
                 f"  Error was: `{exc}`"
             )
@@ -161,7 +159,7 @@ class QueueMessage(threading.Thread):
             # Get roughly 50 percent of the default visibility time.
             # Sleep until that time expires and then increase the
             # message visibility the next time this method is called
-            self._heartbeat.wait(int(self._visibility / 2))
+            self._heartbeat.wait(self._visibility / 2)
             self._worker._check_queue_credentials()
 
             # We keep track of the number of heartbeats this message has had
@@ -223,59 +221,15 @@ class Queue(QalxEntity):
     def _credentials_expiring_soon(self):
         """
         Returns True if the credentials are expiring soon.  The expiration
-        datetime will be a UTC timestamp in isoformat
+        datetime will be a UTC datetime object
         """
-        expiration = dateutil.parser.parse(
-            self["info"]["credentials"]["EXPIRATION"]
-        )
+        expiration = self["info"]["credentials"]["EXPIRATION"]
         # Refresh when 1 hour or less left on the expiration token
         REFRESH_LIMIT_HOURS = 3600
         return (
             expiration - datetime.now(timezone.utc)
         ).seconds <= REFRESH_LIMIT_HOURS
 
-    def submit_sets_from_group(self, group):
-        """
-
-        :param group: a group
-        :type group: `~pyqalx.core.Group`
-        :returns: `pyqalx.core.queue.QueueResponse`
-        """
-
-        responses = []
-
-        for chunk in self._chunks(list(group["sets"].values()), chunk_size=10):
-            chunked_objects = filter(None, chunk)
-            entries = []
-            for _n, set_guid in enumerate(chunked_objects):
-                entries.append(
-                    {
-                        "Id": str(uuid.uuid4()),
-                        "MessageBody": json.dumps(
-                            {
-                                "entity_type": "set",
-                                "entity_guid": set_guid,
-                                "parent_group_guid": group["guid"],
-                            }
-                        ),
-                        # Unique MessageGroupId to prevent processing
-                        # duplicates
-                        "MessageGroupId": str(uuid.uuid4()),
-                        # Unique MessageDeduplicationId to allow the user
-                        # to put the same entity on the queue multiple times
-                        "MessageDeduplicationId": str(uuid.uuid4()),
-                    }
-                )
-
-            if entries:
-                responses.append(
-                    self.broker_client.send_message_batch(
-                        QueueUrl=self["info"]["queue_url"], Entries=entries
-                    )
-                )
-
-        return QueueResponse(responses)
-
     def get_messages(self, max_num_msg, visibility, waittime, worker):
         """
         get messages from the queue
@@ -319,30 +273,102 @@ class Queue(QalxEntity):
             )
             message._stop_heartbeat()
 
-    def submit_entity(self, entity):
-        """put a qalx entity on the queue
-
-        :param entity: entity to add to the queue
-        :type entity: `pyqalx.core.entity.QalxEntity`
-        :return: `pyqalx.core.queue.QueueResponse`
+    def _send_message(self, payload, entity_type, **message_kwargs):
         """
-        if not isinstance(entity, (Item, Set, Group)):
+        Batch submits the given payload to the instance of Queue.  Figures out
+        whether the payload is a subclass of QalxEntity, a string or a list of
+        a combination.  Typically this will be invoked via the entity class itself:
+        i.e. `EntityClass.add_to_queue(entity, queue)`.
+        :param payload:A subclassed instance of QalxEntity, a guid string or a list
+        of QalxEntities/guids
+        :type payload:QalxEntity or str
+        :param entity_type:The entity type
+        :type entity_type: str
+        :param message_kwargs:Additional arguments that should be added to the
+        message body
+        Usage:
+        queue._send_message(<entity_instance>)
+        queue._send_message(<entity_guid>)
+        queue._send_message([<entity_instance>, <entity_instance>, <entity_instance>])
+        queue._send_message([<entity_guid>, <entity_guid>, <entity_guid>])
+        :return:An instance of QueueResponse
+        """
+
+        responses = []
+        valid_types = (QalxEntity, uuid.UUID, list)
+        if not isinstance(payload, valid_types):
+            # Only certain types are supported
             raise QalxQueueError(
-                "Only Item, Set and Group entities can be submitted to the "
-                "queue."
+                f"Expected one of {', '.join([str(vt) for vt in list(valid_types)])}."
+                f" Got {type(payload)}"
             )
-        response = self.broker_client.send_message(
-            QueueUrl=self["info"]["queue_url"],
-            # Unique MessageGroupId to prevent processing duplicates
-            MessageGroupId=str(uuid.uuid4()),
-            # Unique MessageDeduplicationId to allow the user
-            # to put the same entity on the queue multiple times
-            MessageDeduplicationId=str(uuid.uuid4()),
-            MessageBody=self._stringify(
+        if isinstance(payload, (QalxEntity, uuid.UUID)):
+            # Messages always get chunked and added in batches so make
+            # sure the entity is a list if it is of these types
+            payload = [payload]
+        entries = []
+        for _entity in payload:
+            # Build our list of entries to ensure that they are all valid before
+            # submitting to the queue
+            entity_guid = _entity
+            if isinstance(_entity, QalxEntity):
+                # It's an instance of an entity - get the guid for submission
+                # to the queue
+                if not isinstance(_entity, (Item, Set, Group)):
+                    raise QalxQueueError(
+                        "Only Item, Set and Group entities can be submitted to the "
+                        "queue. No messages submitted to queue."
+                    )
+                if _entity.entity_type != entity_type:
+                    error = (
+                        f"Mismatched entity types. Expected "
+                        f"`{entity_type}`, got "
+                        f"`{_entity.entity_type}`. Did you mean to do "
+                        f"`{_entity.__class__.__name__}.add_to_queue("
+                        f"entity, queue)?`. No messages submitted to queue."
+                    )
+                    raise QalxQueueError(error)
+                entity_guid = _entity["guid"]
+
+            entries.append(
                 {
-                    "entity_type": entity.entity_type,
-                    "entity_guid": entity["guid"],
+                    "Id": str(uuid.uuid4()),
+                    "MessageBody": json.dumps(
+                        {
+                            "entity_type": entity_type,
+                            # SQS needs the guid as a string - not UUID
+                            "entity_guid": str(entity_guid),
+                            **message_kwargs,
+                        }
+                    ),
+                    # Unique MessageGroupId to prevent processing
+                    # duplicates.
+                    "MessageGroupId": str(uuid.uuid4()),
+                    # Unique MessageDeduplicationId to allow the user
+                    # to put the same entity on the queue multiple times
+                    "MessageDeduplicationId": str(uuid.uuid4()),
                 }
-            ),
-        )
-        return QueueResponse(response)
+            )
+
+        if entries:
+            MAX_BATCH_SIZE = 10
+            # Iterate through all entries and send them to the queue in batches
+            for chunk in self._chunks(entries, chunk_size=MAX_BATCH_SIZE):
+                chunked_objects = list(filter(None, chunk))
+                responses.append(
+                    self.broker_client.send_message_batch(
+                        QueueUrl=self["info"]["queue_url"],
+                        Entries=chunked_objects,
+                    )
+                )
+
+        return QueueResponse(responses)
+
+    def purge(self):
+        """
+        Purge the queue. All messages on the queue will be deleted.
+
+        This might take up to 60 seconds and any messages sent to the queue
+        while it is being purged might also be deleted
+        """
+        self.broker_client.purge_queue(QueueUrl=self["info"]["queue_url"])
