@@ -632,17 +632,9 @@ class FactoryDemolishMixin:
     Class Attributes
         MAX_BOT_TERMINATE_PROCESSES:    Maximum number of processes to allow for
                                         terminating bots
-        WORKER_SLEEP_LONG:              Long sleep time while waiting for all
-                                        workers to be terminated and none has
-                                        received the signal
-        WORKER_SLEEP_SHORT:             Short sleep time while waiting for all
-                                        workers to be terminated and at least
-                                        one has already received the signal
     """
 
     MAX_BOT_TERMINATE_PROCESSES = 4
-    WORKER_SLEEP_LONG = 5
-    WORKER_SLEEP_SHORT = 1
 
     def get_workflow(self):
         """
@@ -672,57 +664,54 @@ class FactoryDemolishMixin:
 
     def wait_on_bot_termination(self, bot):
         """
-        For a provided bot, iterates through all the workers and returns only
-        after it has been asserted that all workers have been warm terminated.
+        For a provided bot entity, iterates through all the workers and returns
+        only after it has been asserted that all workers have been warm
+        terminated.
 
         :param bot:     The bot to wait on until all workers are warm terminated
         """
-        # This flag can be used to determine the sleep time while waiting for
-        # the workers to be terminated. If True then the sleep time between
-        # checking for worker termination is WORKER_SLEEP_SHORT otherwise
-        # WORKER_SLEEP_LONG. The long sleeping time is used when none of the
-        # workers has received the warm terminate signal in order to minimise
-        # the number of requests to the API. Once at least one of the workers
-        # has received the signal, the rest of the workers are expected to
-        # receive it in a similar time-frame, so the sleep time is decreased
-        sleep_short_flag = False
-        while True:
-            terminated_signals = []
-            for worker in bot["workers"]:
-                terminated_signals.append(
-                    self.session.worker.get_signal(worker, bot).terminate_warm
-                )
-                if sleep_short_flag:
-                    sleep(self.WORKER_SLEEP_SHORT)
-                else:
-                    sleep(self.WORKER_SLEEP_LONG)
-            if sleep_short_flag is False and any(terminated_signals):
-                sleep_short_flag = True
-                continue
-            if all(terminated_signals):
-                return
+
+        def _terminate_warm(_bot):
+            # Helper for returning the `terminate_warm` signal of all works
+            # on a given bot
+            return [
+                self.session.worker.signal_class(_worker).terminate_warm
+                for _worker in _bot["workers"]
+            ]
+
+        terminated_signals = _terminate_warm(bot)
+
+        while not all(terminated_signals):
+            # sleep, to prevent hitting the API too many times while waiting
+            # for termination.
+            sleep(5)
+            bot = self.session.bot.reload(bot)
+            terminated_signals = _terminate_warm(bot)
 
     def safe_terminate_bot(self, plan_bot_name):
         """
         Safely terminate one or more bots with the provided plan name. Calls
         bot.terminate with warm=True on the specified bots and then for each of
-        the bots calls wait_on_bot_termination.
-
+        the bots calls wait_on_bot_termination.  There may be multiple bots
+        with the same name - i.e. same bot on different sectors.  These can
+        be safely terminated in parallel as this method is only called with
+        the correct bot names for the correct point in the workflow
         :param  plan_bot_name:   The name of the bot to terminate on the plan
         :type   plan_bot_name    str
-
         :return bot_name
         """
         self._msg_user(msg=f"[{plan_bot_name}] terminating")
-        bots = []
-        for (_, _plan_bot_name), bot in self.bots.items():
-            if _plan_bot_name == plan_bot_name:
-                bots.append(bot)
-        for bot in bots:
-            # Send termination signal to all affected bots.
-            self.session.bot.terminate(entity=bot, warm=True)
-        for bot in bots:
-            self.wait_on_bot_termination(bot)
+        with concurrent.futures.ThreadPoolExecutor(
+            max_workers=self.MAX_BOT_TERMINATE_PROCESSES
+        ) as executor:
+            for (_, _plan_bot_name), bot in self.bots.items():
+                if _plan_bot_name == plan_bot_name:
+                    # Send termination signal to all affected bots.
+                    # and wait for termination to complete.
+                    executor.submit(
+                        self.session.bot.terminate, entity=bot, warm=True
+                    )
+                    executor.submit(self.wait_on_bot_termination, bot)
         self._msg_user(msg=f"[{plan_bot_name}] terminated successfully")
         return plan_bot_name
 
