@@ -30,11 +30,19 @@ class QalxImport(click.ParamType):
         super(QalxImport, self).__init__(*args, **kwargs)
 
     def convert(self, value, param, ctx):
-        module_name, variable_name = value.split(":")
+        msg = "Argument must be in the format `dotted.path.to:variable_name`"
+        try:
+            module_name, variable_name = value.split(":")
+        except ValueError as exc:
+            # ValueError: No `:` in string
+            msg = f"{msg}.  Error was `{exc}`"
+            self.fail(msg)
         try:
             module = import_module(module_name)
-        except ImportError:
-            self.fail(f"Failed to import `{module_name}`")
+        except ImportError as exc:
+            # ImportError: Invalid path
+            msg = f"{msg}.  Error was `{exc}`"
+            self.fail(msg)
         if variable_name not in dir(module):
             self.fail(f"`{variable_name}` not found in `{module_name}`.")
         _import_target = getattr(module, variable_name)
@@ -121,3 +129,5 @@ BOT_CONFIG_IMPORT = QalxImport(BotConfig)
 QALX_ENTITY_IMPORT = QalxImport(QalxEntity)
 QALX_FACTORY_STAGE = QalxFactoryStage()
 QALX_DICT = QalxDict()
+POSITIVE_INT = click.IntRange(min=1)
+FILE_PATH_EXISTING = click.types.Path(exists=True, file_okay=True)
